@@ -1,4 +1,3 @@
-import csv
 import json
 import os
 import pathlib
@@ -10,8 +9,6 @@ import typer
 from neosctl import util
 from neosctl.auth import ensure_login
 from neosctl.schema import DataProductCreate
-from neosctl.schema import FieldDataType
-from neosctl.schema import FieldDefinition
 from neosctl.util import process_response
 
 
@@ -40,35 +37,28 @@ def template(
 
     Given a csv with a header row, generate a template field schema.
     """
+    @ensure_login
+    def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
+        params = {k: v for k, v in [("delimiter", delimiter), ("quotechar", quotechar)] if v is not None}
+
+        return util.post(
+            ctx,
+            "{dp_url}/template".format(dp_url=product_url(ctx)),
+            params=params,
+            files={"csv_file": f},
+        )
+
     fp = util.get_file_location(filepath)
 
-    delimiter = special_delimiters.get(delimiter, delimiter)
+    with fp.open("rb") as f:
+        r = _request(ctx, f)
 
-    kwargs = {k: v for k, v in [("delimiter", delimiter), ("quotechar", quotechar)] if v is not None}
-
-    with fp.open() as f:
-        reader = csv.DictReader(f, **kwargs)
-        fields = reader.fieldnames
-
-    output = []
-    for field in fields:
-        output.append(
-            FieldDefinition(
-                name=field,
-                description=None,
-                type="STRING",
-                primary=False,
-                optional=False,
-                data_type=FieldDataType(
-                    meta={},
-                    type="TEXT",
-                ),
-            ).dict(),
-        )
+    if r.status_code >= 400:
+        process_response(r)
 
     fp = pathlib.Path(output_dir) / "{}.json".format(name)
     with fp.open("w") as f:
-        json.dump(output, f, indent=4)
+        json.dump(r.json(), f, indent=4)
 
 
 @app.command(name="create")
