@@ -39,6 +39,11 @@ def init(
         "--ignore-tls",
         help="Ignore TLS errors (useful in local/development environments",
     ),
+    non_interactive: bool = typer.Option(
+        False,
+        "--non-interactive",
+        help="Don't ask for input, generate api values based on hostname.",
+    ),
 ):
     """Initialise a profile.
 
@@ -50,6 +55,18 @@ def init(
     typer.echo("Initialising [{}] profile.".format(ctx.obj.profile_name))
     default_host = "{}/api/{{}}".format(hostname) if hostname else ""
 
+    if non_interactive and not (hostname and username):
+        send_output(
+            msg="\nError: --hostname/-h and --username/-u required for non-interactive mode.",
+            exit_code=1,
+        )
+
+    if non_interactive:
+        gateway_api_url = gateway_api_url or "{}/api/gateway".format(hostname)
+        storage_api_url = storage_api_url or "{}/api/storage".format(hostname)
+        iam_api_url = iam_api_url or "{}/api/iam".format(hostname)
+        registry_api_url = registry_api_url or "{}/api/registry".format(hostname)
+
     urls = {
         "gateway_api_url": gateway_api_url,
         "registry_api_url": registry_api_url,
