@@ -27,14 +27,6 @@ def add_job(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     job_filepath: str = typer.Option(..., "--job-filepath", "-f"),
-    docker_tag: str = typer.Option("v0.1.34", "--docker-tag", "-d"),
-    executor_cores: int = typer.Option(1, "--executor-cores", "-ec"),
-    executor_instances: int = typer.Option(1, "--executor-instances", "-ei"),
-    executor_memory: str = typer.Option("512m", "--executor-memory", "-em"),
-    driver_cores: int = typer.Option(1, "--driver-cores", "-dc"),
-    driver_core_limit: str = typer.Option("1200m", "--driver-core-limit", "-dcl"),
-    driver_memory: str = typer.Option("512m", "--driver-memory", "-dm"),
-    spark_version: str = typer.Option("3.1.1", "--spark-version", "-sv"),
 ):
     """Assign a spark job.
 
@@ -46,17 +38,7 @@ def add_job(
         return util.post(
             ctx,
             spark_url(product_name, ctx.obj.gateway_api_url),
-            params={
-                "docker_tag": docker_tag,
-                "executor_cores": executor_cores,
-                "executor_instances": executor_instances,
-                "executor_memory": executor_memory,
-                "driver_cores": driver_cores,
-                "driver_core_limit": driver_core_limit,
-                "driver_memory": driver_memory,
-                "spark_version": spark_version,
-            },
-            files={"python_file": f},
+            files={"spark_file": f},
         )
 
     fp = util.get_file_location(job_filepath)
@@ -112,14 +94,6 @@ def update_job(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     job_filepath: str = typer.Option(None, "--job-filepath", "-f"),
-    docker_tag: str = typer.Option(None, "--docker-tag", "-d"),
-    executor_cores: int = typer.Option(None, "--executor-cores", "-ec"),
-    executor_instances: int = typer.Option(None, "--executor-instances", "-ei"),
-    executor_memory: str = typer.Option(None, "--executor-memory", "-em"),
-    driver_cores: int = typer.Option(None, "--driver-cores", "-dc"),
-    driver_core_limit: str = typer.Option(None, "--driver-core-limit", "-dcl"),
-    driver_memory: str = typer.Option(None, "--driver-memory", "-dm"),
-    spark_version: str = typer.Option(None, "--spark-version", "-sv"),
 ):
     """Update an assigned spark job.
 
@@ -130,26 +104,11 @@ def update_job(
         ctx: typer.Context,
         f: typing.Optional[typing.IO],
     ) -> httpx.Response:
-        params = {
-            k: v
-            for k, v in [
-                ("docker_tag", docker_tag),
-                ("executor_cores", executor_cores),
-                ("executor_instances", executor_instances),
-                ("executor_memory", executor_memory),
-                ("driver_cores", driver_cores),
-                ("driver_core_limit", driver_core_limit),
-                ("driver_memory", driver_memory),
-                ("spark_version", spark_version),
-            ]
-            if v is not None
-        }
-        files = {"python_file": f} if f else {}
+        files = {"spark_file": f} if f else {}
 
         return util.put(
             ctx,
             spark_url(product_name, ctx.obj.gateway_api_url),
-            params=params,
             files=files,
         )
 
@@ -202,6 +161,42 @@ def trigger_job(
     process_response(r)
 
 
+@app.command()
+def csv_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    delimiter: str = typer.Option(",", "--delimiter", "-d", help="csv delimiter"),
+    quotechar: typing.Optional[str] = typer.Option(None, "--quote-char", "-q", help="csv quote char"),
+    job_filepath: str = typer.Option(..., "--job-filepath", "-f"),
+):
+    """Ingest a csv file into a data product.
+
+    Upload a csv file for processing into a data product.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
+        params = {
+            "delimiter": delimiter,
+        }
+
+        if quotechar is not None:
+            params["quotechar"] = quotechar
+
+        return util.post(
+            ctx,
+            "{spark_url}/csv".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            params=params,
+            files={"csv_file": f},
+        )
+
+    fp = util.get_file_location(job_filepath)
+
+    with fp.open("rb") as f:
+        r = _request(ctx, f)
+
+    process_response(r)
+
+
 @app.command()
 def schedule_job(
     ctx: typer.Context,
